#r "nuget: System.ServiceModel.Syndication, 8.0.0"

open System
open System.ServiceModel.Syndication

let web = new Net.Http.HttpClient()

let getFeedAsync (uri:string) =
  async {
    let! ct = Async.CancellationToken
    try
      use! rs = web.GetStreamAsync(uri, ct) |> Async.AwaitTask
      use xr = Xml.XmlReader.Create(rs)
      return Ok (SyndicationFeed.Load xr)
    with
    | err ->
      return Error err
  }

[|
  "https://foundation.fsharp.org/announcements.rss"
  "https://www.tagesschau.de/xml/rss2/"
|]
|> Array.map getFeedAsync
|> Async.Parallel
|> Async.RunSynchronously
|> Array.iter (function
  | Ok feed ->
    for it in feed.Items do
      printfn "- %s" it.Title.Text
  | Error err ->
    printfn "Error: %O" err
)

web.Dispose()
