#r "nuget: XPlot.Plotly, 4.0.6"
#load "AutoDiff.fs"

open FSharp.Data.UnitSystems.SI.UnitSymbols
open Murphy.AutoDiff
open XPlot.Plotly

let g = 9.81<m/s^2>

let fall (t:DFloat<s>) = g/2.0 * t*t

let points =
  [ 0.0 .. 10.0 ]
  |> List.map (fun t ->
    let t = DFloat.Var (t * 1.0<s>)
    t, fall t
  )
  
let chart =
  let xs = points |> List.map (fun (t, _) -> t.Value / 1.0<s>)
  let zs = points |> List.map (fun (_, z) -> z.Value / 1.0<m>)
  let vs = points |> List.map (fun (t, z) -> z.Derive(t).Value / 1.0<m/s>)
  
  Chart.Plot [
    Scatter(x = xs, y = zs, mode = "lines", name = "z [m]")
    Scatter(x = xs, y = vs, mode = "lines", name = "v [m/s]")
  ]
  |> Chart.WithLayout (Layout(
    title = "Free Fall",
    xaxis = Xaxis(title = "t [s]")
  ))

chart
|> Chart.WithWidth 640 
|> Chart.WithHeight 640
|> Chart.Show
